CIDU 2012: Introduction to astroML
----------------------------------
These figures are from the introduction to the astroML package presented at
the Conference for Intelligent Data Understanding (CIDU) 2012.
